@@ -39,11 +39,7 @@ class TaskValidator(MapBuilder):
                 "output.structure",
                 "output.bandgap",
                 "chemsys",
-                "calcs_reversed.output.ionic_steps.electronic_steps.e_fr_energy",
-                "tags",
-                # Need these two for proper run_type determination
-                "calcs_reversed.input.parameters",
-                "calcs_reversed.input.incar",
+                "calcs_reversed",
             ],
             query=query,
             **kwargs,
